@@ -1,7 +1,7 @@
-from parchmint.layer import Layer
-
 from enum import Enum
 
+from parchmint.layer import Layer
+
 
 class MINTLayerType(Enum):
     FLOW = 1
@@ -35,6 +35,10 @@ class MINTLayerType(Enum):
 
 
 class MINTLayer(Layer):
+    """MINT Layer class that abstracts the Layer class and adds additional
+    methods to help generating MINT
+    """
+
     def __init__(
         self,
         id: str,
